IsTableCell class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- IsTableCell
Constructors
-
IsTableCell({Key? key, required Widget primaryContent, required IsTableDataType isTableDataType, double width = 20, double gapBetweenContent = 5, BoxDecoration cellStyle = const BoxDecoration(), AlignmentGeometry cellContentAlignment = Alignment.centerLeft, EdgeInsetsGeometry cellMargin = const EdgeInsets.all(0), EdgeInsetsGeometry cellPadding = const EdgeInsets.all(0), void onCellTap()?, void onCellDoubleTap()?, void onCellLongPress()?, void onCellTapDown(TapDownDetails)?, void onCellTapUp(TapUpDetails)?, void onCellTapCancel()?, void onCellSecondaryTap()?, void onCellSecondaryTapUp(TapUpDetails)?, void onCellSecondaryTapDown(TapDownDetails)?, void onCellSecondaryTapCancel()?, void onCellHighlightChanged(bool)?, void onCellHover(bool)?, MouseCursor? cellMouseCursor, Color? cellFocusColor, Color? cellighlightColor, MaterialStateProperty<
Color?> ? cellOverlayColor, Color? cellSplashColor, InteractiveInkFeatureFactory? cellSplashFactory, double? cellRadius, BorderRadius? cellBorderRadius, ShapeBorder? cellCustomBorder, bool cellEnableFeedback = true, bool cellExcludeFromSemantics = false, FocusNode? cellFocusNode, bool cellCanRequestFocus = true, void oncCellFocusChange(bool)?, bool cellAutofocus = false, MaterialStatesController? cellStatesController, Duration? cellHoverDuration})
Properties
- cellAutofocus ↔ bool
-
getter/setter pair
- cellBorderRadius ↔ BorderRadius?
-
getter/setter pair
- cellCanRequestFocus ↔ bool
-
getter/setter pair
- cellContentAlignment → AlignmentGeometry
-
final
- cellCustomBorder ↔ ShapeBorder?
-
getter/setter pair
- cellEnableFeedback ↔ bool
-
getter/setter pair
- cellExcludeFromSemantics ↔ bool
-
getter/setter pair
- cellFocusColor ↔ Color?
-
getter/setter pair
- cellFocusNode ↔ FocusNode?
-
getter/setter pair
- cellHoverColor ↔ Color?
-
getter/setter pair
- cellHoverDuration ↔ Duration?
-
getter/setter pair
- cellighlightColor ↔ Color?
-
getter/setter pair
- cellMargin → EdgeInsetsGeometry
-
final
- cellMouseCursor ↔ MouseCursor?
-
getter/setter pair
-
cellOverlayColor
↔ MaterialStateProperty<
Color?> ? -
getter/setter pair
- cellPadding → EdgeInsetsGeometry
-
final
- cellRadius ↔ double?
-
getter/setter pair
- cellSplashColor ↔ Color?
-
getter/setter pair
- cellSplashFactory ↔ InteractiveInkFeatureFactory?
-
getter/setter pair
- cellStatesController ↔ MaterialStatesController?
-
getter/setter pair
- cellStyle → BoxDecoration
-
final
- gapBetweenContent → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTableDataType → IsTableDataType
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- oncCellFocusChange ↔ void Function(bool)?
-
getter/setter pair
- onCellDoubleTap → void Function()?
-
final
- onCellHighlightChanged → void Function(bool)?
-
final
- onCellHover → void Function(bool)?
-
final
- onCellLongPress → void Function()?
-
final
- onCellSecondaryTap → void Function()?
-
final
- onCellSecondaryTapCancel → void Function()?
-
final
- onCellSecondaryTapDown → void Function(TapDownDetails)?
-
final
- onCellSecondaryTapUp → void Function(TapUpDetails)?
-
final
- onCellTap → void Function()?
-
final
- onCellTapCancel → void Function()?
-
final
- onCellTapDown → void Function(TapDownDetails)?
-
final
- onCellTapUp → void Function(TapUpDetails)?
-
final
- primaryContent → Widget
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited